package com.ruoyi.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.domain.PsaMaterialApply;
import com.ruoyi.service.IPsaMaterialApplyService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 物品领用申请Controller
 * 
 * @author fangjianyu
 * @date 2025-02-28
 */
@RestController
@RequestMapping("/material/apply")
public class PsaMaterialApplyController extends BaseController
{
    @Autowired
    private IPsaMaterialApplyService psaMaterialApplyService;

    /**
     * 查询物品领用申请列表
     */
    @PreAuthorize("@ss.hasPermi('material:apply:list')")
    @GetMapping("/list")
    public TableDataInfo list(PsaMaterialApply psaMaterialApply)
    {
        startPage();
        List<PsaMaterialApply> list = psaMaterialApplyService.selectPsaMaterialApplyList(psaMaterialApply);
        return getDataTable(list);
    }

    /**
     * 导出物品领用申请列表
     */
    @PreAuthorize("@ss.hasPermi('material:apply:export')")
    @Log(title = "物品领用申请", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PsaMaterialApply psaMaterialApply)
    {
        List<PsaMaterialApply> list = psaMaterialApplyService.selectPsaMaterialApplyList(psaMaterialApply);
        ExcelUtil<PsaMaterialApply> util = new ExcelUtil<PsaMaterialApply>(PsaMaterialApply.class);
        util.exportExcel(response, list, "物品领用申请数据");
    }

    /**
     * 获取物品领用申请详细信息
     */
    @PreAuthorize("@ss.hasPermi('material:apply:query')")
    @GetMapping(value = "/{applyId}")
    public AjaxResult getInfo(@PathVariable("applyId") Long applyId)
    {
        return success(psaMaterialApplyService.selectPsaMaterialApplyByApplyId(applyId));
    }

    /**
     * 新增物品领用申请
     */
    @PreAuthorize("@ss.hasPermi('material:apply:add')")
    @Log(title = "物品领用申请", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PsaMaterialApply psaMaterialApply)
    {
        return toAjax(psaMaterialApplyService.insertPsaMaterialApply(psaMaterialApply));
    }

    /**
     * 修改物品领用申请
     */
    @PreAuthorize("@ss.hasPermi('material:apply:edit')")
    @Log(title = "物品领用申请", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PsaMaterialApply psaMaterialApply)
    {
        return toAjax(psaMaterialApplyService.updatePsaMaterialApply(psaMaterialApply));
    }

    /**
     * 删除物品领用申请
     */
    @PreAuthorize("@ss.hasPermi('material:apply:remove')")
    @Log(title = "物品领用申请", businessType = BusinessType.DELETE)
	@DeleteMapping("/{applyIds}")
    public AjaxResult remove(@PathVariable Long[] applyIds)
    {
        return toAjax(psaMaterialApplyService.deletePsaMaterialApplyByApplyIds(applyIds));
    }
}
