package com.ruoyi.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.domain.PsaMaterial;
import com.ruoyi.service.IPsaMaterialService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 物品信息Controller
 * 
 * @author fangjianyu
 * @date 2025-02-28
 */
@RestController
@RequestMapping("/material/material")
public class PsaMaterialController extends BaseController
{
    @Autowired
    private IPsaMaterialService psaMaterialService;

    /**
     * 查询物品信息列表
     */
    @PreAuthorize("@ss.hasPermi('material:material:list')")
    @GetMapping("/list")
    public TableDataInfo list(PsaMaterial psaMaterial)
    {
        startPage();
        List<PsaMaterial> list = psaMaterialService.selectPsaMaterialList(psaMaterial);
        return getDataTable(list);
    }

    /**
     * 导出物品信息列表
     */
    @PreAuthorize("@ss.hasPermi('material:material:export')")
    @Log(title = "物品信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PsaMaterial psaMaterial)
    {
        List<PsaMaterial> list = psaMaterialService.selectPsaMaterialList(psaMaterial);
        ExcelUtil<PsaMaterial> util = new ExcelUtil<PsaMaterial>(PsaMaterial.class);
        util.exportExcel(response, list, "物品信息数据");
    }

    /**
     * 获取物品信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('material:material:query')")
    @GetMapping(value = "/{materialId}")
    public AjaxResult getInfo(@PathVariable("materialId") Long materialId)
    {
        return success(psaMaterialService.selectPsaMaterialByMaterialId(materialId));
    }

    /**
     * 新增物品信息
     */
    @PreAuthorize("@ss.hasPermi('material:material:add')")
    @Log(title = "物品信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PsaMaterial psaMaterial)
    {
        return toAjax(psaMaterialService.insertPsaMaterial(psaMaterial));
    }

    /**
     * 修改物品信息
     */
    @PreAuthorize("@ss.hasPermi('material:material:edit')")
    @Log(title = "物品信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PsaMaterial psaMaterial)
    {
        return toAjax(psaMaterialService.updatePsaMaterial(psaMaterial));
    }

    /**
     * 删除物品信息
     */
    @PreAuthorize("@ss.hasPermi('material:material:remove')")
    @Log(title = "物品信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{materialIds}")
    public AjaxResult remove(@PathVariable Long[] materialIds)
    {
        return toAjax(psaMaterialService.deletePsaMaterialByMaterialIds(materialIds));
    }
}
