package com.ruoyi.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.domain.PsaMaterialEntry;
import com.ruoyi.service.IPsaMaterialEntryService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 物品入库信息Controller
 * 
 * @author fangjianyu
 * @date 2025-02-28
 */
@RestController
@RequestMapping("/material/entry")
public class PsaMaterialEntryController extends BaseController
{
    @Autowired
    private IPsaMaterialEntryService psaMaterialEntryService;

    /**
     * 查询物品入库信息列表
     */
    @PreAuthorize("@ss.hasPermi('material:entry:list')")
    @GetMapping("/list")
    public TableDataInfo list(PsaMaterialEntry psaMaterialEntry)
    {
        startPage();
        List<PsaMaterialEntry> list = psaMaterialEntryService.selectPsaMaterialEntryList(psaMaterialEntry);
        return getDataTable(list);
    }

    /**
     * 导出物品入库信息列表
     */
    @PreAuthorize("@ss.hasPermi('material:entry:export')")
    @Log(title = "物品入库信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PsaMaterialEntry psaMaterialEntry)
    {
        List<PsaMaterialEntry> list = psaMaterialEntryService.selectPsaMaterialEntryList(psaMaterialEntry);
        ExcelUtil<PsaMaterialEntry> util = new ExcelUtil<PsaMaterialEntry>(PsaMaterialEntry.class);
        util.exportExcel(response, list, "物品入库信息数据");
    }

    /**
     * 获取物品入库信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('material:entry:query')")
    @GetMapping(value = "/{entryId}")
    public AjaxResult getInfo(@PathVariable("entryId") Long entryId)
    {
        return success(psaMaterialEntryService.selectPsaMaterialEntryByEntryId(entryId));
    }

    /**
     * 新增物品入库信息
     */
    @PreAuthorize("@ss.hasPermi('material:entry:add')")
    @Log(title = "物品入库信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PsaMaterialEntry psaMaterialEntry)
    {
        return toAjax(psaMaterialEntryService.insertPsaMaterialEntry(psaMaterialEntry));
    }

    /**
     * 修改物品入库信息
     */
    @PreAuthorize("@ss.hasPermi('material:entry:edit')")
    @Log(title = "物品入库信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PsaMaterialEntry psaMaterialEntry)
    {
        return toAjax(psaMaterialEntryService.updatePsaMaterialEntry(psaMaterialEntry));
    }

    /**
     * 删除物品入库信息
     */
    @PreAuthorize("@ss.hasPermi('material:entry:remove')")
    @Log(title = "物品入库信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{entryIds}")
    public AjaxResult remove(@PathVariable Long[] entryIds)
    {
        return toAjax(psaMaterialEntryService.deletePsaMaterialEntryByEntryIds(entryIds));
    }
}
