package com.ruoyi.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.domain.PsaMaterialReturn;
import com.ruoyi.service.IPsaMaterialReturnService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 物品归还申请Controller
 * 
 * @author fangjianyu
 * @date 2025-02-28
 */
@RestController
@RequestMapping("/material/return")
public class PsaMaterialReturnController extends BaseController
{
    @Autowired
    private IPsaMaterialReturnService psaMaterialReturnService;

    /**
     * 查询物品归还申请列表
     */
    @PreAuthorize("@ss.hasPermi('material:return:list')")
    @GetMapping("/list")
    public TableDataInfo list(PsaMaterialReturn psaMaterialReturn)
    {
        startPage();
        List<PsaMaterialReturn> list = psaMaterialReturnService.selectPsaMaterialReturnList(psaMaterialReturn);
        return getDataTable(list);
    }

    /**
     * 导出物品归还申请列表
     */
    @PreAuthorize("@ss.hasPermi('material:return:export')")
    @Log(title = "物品归还申请", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PsaMaterialReturn psaMaterialReturn)
    {
        List<PsaMaterialReturn> list = psaMaterialReturnService.selectPsaMaterialReturnList(psaMaterialReturn);
        ExcelUtil<PsaMaterialReturn> util = new ExcelUtil<PsaMaterialReturn>(PsaMaterialReturn.class);
        util.exportExcel(response, list, "物品归还申请数据");
    }

    /**
     * 获取物品归还申请详细信息
     */
    @PreAuthorize("@ss.hasPermi('material:return:query')")
    @GetMapping(value = "/{returnId}")
    public AjaxResult getInfo(@PathVariable("returnId") Long returnId)
    {
        return success(psaMaterialReturnService.selectPsaMaterialReturnByReturnId(returnId));
    }

    /**
     * 新增物品归还申请
     */
    @PreAuthorize("@ss.hasPermi('material:return:add')")
    @Log(title = "物品归还申请", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PsaMaterialReturn psaMaterialReturn)
    {
        return toAjax(psaMaterialReturnService.insertPsaMaterialReturn(psaMaterialReturn));
    }

    /**
     * 修改物品归还申请
     */
    @PreAuthorize("@ss.hasPermi('material:return:edit')")
    @Log(title = "物品归还申请", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PsaMaterialReturn psaMaterialReturn)
    {
        return toAjax(psaMaterialReturnService.updatePsaMaterialReturn(psaMaterialReturn));
    }

    /**
     * 删除物品归还申请
     */
    @PreAuthorize("@ss.hasPermi('material:return:remove')")
    @Log(title = "物品归还申请", businessType = BusinessType.DELETE)
	@DeleteMapping("/{returnIds}")
    public AjaxResult remove(@PathVariable Long[] returnIds)
    {
        return toAjax(psaMaterialReturnService.deletePsaMaterialReturnByReturnIds(returnIds));
    }
}
